/*----- PROTECTED REGION ID(Ows.cpp) ENABLED START -----*/
static const char *RcsId = "$Id: Ows.cpp,v 1.10 2018-05-24 09:22:24 alessio Exp $";
//=============================================================================
//
// file :        Ows.cpp
//
// description : C++ source for the Ows class and its commands.
//               The class is derived from Device. It represents the
//               CORBA servant object which will be accessed from the
//               network. All commands which can be executed on the
//               Ows are implemented in this file.
//
// project :     
//
// This file is part of Tango device class.
// 
// Tango is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Tango is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with Tango.  If not, see <http://www.gnu.org/licenses/>.
// 
// $Author: alessio $
//
// $Revision: 1.10 $
// $Date: 2018-05-24 09:22:24 $
//
// $HeadURL:  $
//
//=============================================================================
//                This file is generated by POGO
//        (Program Obviously used to Generate tango Object)
//=============================================================================


#include <Ows.h>
#include <OwsClass.h>

#define MAX_DEVSTRING_LENGTH 255

/*----- PROTECTED REGION END -----*/	//	Ows.cpp

/**
 *  Ows class description:
 *    
 */

//================================================================
//  The following table gives the correspondence
//  between command and method names.
//
//  Command name  |  Method name
//================================================================
//  State         |  Inherited (no method)
//  Status        |  Inherited (no method)
//================================================================

//================================================================
//  Attributes managed are:
//================================================================
//  Firmware          |  Tango::DevString	Scalar
//  AvailableDevices  |  Tango::DevUShort	Scalar
//================================================================

namespace Ows_ns
{
/*----- PROTECTED REGION ID(Ows::namespace_starting) ENABLED START -----*/

//	static initializations

/*----- PROTECTED REGION END -----*/	//	Ows::namespace_starting

//--------------------------------------------------------
/**
 *	Method      : Ows::Ows()
 *	Description : Constructors for a Tango device
 *                implementing the classOws
 */
//--------------------------------------------------------
Ows::Ows(Tango::DeviceClass *cl, string &s)
 : SnmpClient(cl, s.c_str())
{
	/*----- PROTECTED REGION ID(Ows::constructor_1) ENABLED START -----*/
	init_device();
	
	/*----- PROTECTED REGION END -----*/	//	Ows::constructor_1
}
//--------------------------------------------------------
Ows::Ows(Tango::DeviceClass *cl, const char *s)
 : SnmpClient(cl, s)
{
	/*----- PROTECTED REGION ID(Ows::constructor_2) ENABLED START -----*/
	init_device();
	
	/*----- PROTECTED REGION END -----*/	//	Ows::constructor_2
}
//--------------------------------------------------------
Ows::Ows(Tango::DeviceClass *cl, const char *s, const char *d)
 : SnmpClient(cl, s, d)
{
	/*----- PROTECTED REGION ID(Ows::constructor_3) ENABLED START -----*/
	init_device();
	
	/*----- PROTECTED REGION END -----*/	//	Ows::constructor_3
}

//--------------------------------------------------------
/**
 *	Method      : Ows::delete_device()
 *	Description : will be called at device destruction or at init command
 */
//--------------------------------------------------------
void Ows::delete_device()
{
	DEBUG_STREAM << "Ows::delete_device() " << device_name << endl;
	/*----- PROTECTED REGION ID(Ows::delete_device) ENABLED START -----*/
	
	//	Delete device allocated objects
	delete attr_Firmware_read[0];
	
	/*----- PROTECTED REGION END -----*/	//	Ows::delete_device
	delete[] attr_Firmware_read;
	delete[] attr_AvailableDevices_read;

	if (Tango::Util::instance()->is_svr_shutting_down()==false  &&
		Tango::Util::instance()->is_device_restarting(device_name)==false &&
		Tango::Util::instance()->is_svr_starting()==false)
	{
		//	If not shutting down call delete device for inherited object
		SnmpClient_ns::SnmpClient::delete_device();
	}
}

//--------------------------------------------------------
/**
 *	Method      : Ows::init_device()
 *	Description : will be called at device initialization.
 */
//--------------------------------------------------------
void Ows::init_device()
{
	DEBUG_STREAM << "Ows::init_device() create device " << device_name << endl;
	/*----- PROTECTED REGION ID(Ows::init_device_before) ENABLED START -----*/
	
	//	Initialization before get_device_property() call
	mandatoryNotDefined = false;
	init_error.clear();
	
	/*----- PROTECTED REGION END -----*/	//	Ows::init_device_before
	
	if (Tango::Util::instance()->is_svr_starting() == false  &&
		Tango::Util::instance()->is_device_restarting(device_name)==false)
	{
		//	If not starting up call init device for inherited object
		SnmpClient_ns::SnmpClient::init_device();
	}
	//	No device property to be read from database
	
	attr_Firmware_read = new Tango::DevString[1];
	attr_AvailableDevices_read = new Tango::DevUShort[1];
	//	No longer if mandatory property not set. 
	if (mandatoryNotDefined)
		return;

	/*----- PROTECTED REGION ID(Ows::init_device) ENABLED START -----*/
	
	//	Initialize device
	try {
		get("EDS-MIB::owDeviceNumActive.0", number_of_sensors);
		set_state(Tango::ON);
	} catch (Tango::DevFailed &e) {
		set_state(Tango::FAULT);
		init_error = "Initialization failed: " + string(e.errors[0].desc);
	} catch (...) {
		set_state(Tango::UNKNOWN);
		init_error = "Initialization failed: Unknown error";
	}
		
	attr_Firmware_read[0] = new char[MAX_DEVSTRING_LENGTH];
	
	/*----- PROTECTED REGION END -----*/	//	Ows::init_device
}


//--------------------------------------------------------
/**
 *	Method      : Ows::always_executed_hook()
 *	Description : method always executed before any command is executed
 */
//--------------------------------------------------------
void Ows::always_executed_hook()
{
	DEBUG_STREAM << "Ows::always_executed_hook()  " << device_name << endl;
	if (mandatoryNotDefined)
	{
		string	status(get_status());
		Tango::Except::throw_exception(
					(const char *)"PROPERTY_NOT_SET",
					status.c_str(),
					(const char *)"Ows::always_executed_hook()");
	}
	/*----- PROTECTED REGION ID(Ows::always_executed_hook) ENABLED START -----*/
	
	//	code always executed before all requests
	SnmpClient_ns::SnmpClient::always_executed_hook();

	if (! init_error.empty()) {
		set_state(Tango::FAULT);
		set_status(init_error);
		return;
	}

	try {	
		check_state();
	} catch (Tango::DevFailed &e) {
		set_state(Tango::FAULT);
		set_status(string( e.errors[0].desc ));
	} catch (...) {
		set_state(Tango::FAULT);
		set_status("Unknown error");
	}
	
	/*----- PROTECTED REGION END -----*/	//	Ows::always_executed_hook
}

//--------------------------------------------------------
/**
 *	Method      : Ows::read_attr_hardware()
 *	Description : Hardware acquisition for attributes
 */
//--------------------------------------------------------
void Ows::read_attr_hardware(TANGO_UNUSED(vector<long> &attr_list))
{
	DEBUG_STREAM << "Ows::read_attr_hardware(vector<long> &attr_list) entering... " << endl;
	/*----- PROTECTED REGION ID(Ows::read_attr_hardware) ENABLED START -----*/
	
	//	Add your own code
	check_init();
	
	/*----- PROTECTED REGION END -----*/	//	Ows::read_attr_hardware
}

//--------------------------------------------------------
/**
 *	Read attribute Firmware related method
 *	Description: 
 *
 *	Data type:	Tango::DevString
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void Ows::read_Firmware(Tango::Attribute &attr)
{
	DEBUG_STREAM << "Ows::read_Firmware(Tango::Attribute &attr) entering... " << endl;
	/*----- PROTECTED REGION ID(Ows::read_Firmware) ENABLED START -----*/
	//	Set the attribute value
	string firmware;
	get("EDS-MIB::eFirmwareVersion.0", firmware);
	if (firmware[0] == '"')
		firmware = firmware.substr(1, firmware.size() - 2);
	strncpy(attr_Firmware_read[0], firmware.c_str(), MAX_DEVSTRING_LENGTH);

	attr.set_value(attr_Firmware_read);
	
	/*----- PROTECTED REGION END -----*/	//	Ows::read_Firmware
}
//--------------------------------------------------------
/**
 *	Read attribute AvailableDevices related method
 *	Description: 
 *
 *	Data type:	Tango::DevUShort
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void Ows::read_AvailableDevices(Tango::Attribute &attr)
{
	DEBUG_STREAM << "Ows::read_AvailableDevices(Tango::Attribute &attr) entering... " << endl;
	/*----- PROTECTED REGION ID(Ows::read_AvailableDevices) ENABLED START -----*/
	//	Set the attribute value
	get("EDS-MIB::owDeviceNumActive.0", attr_AvailableDevices_read[0]);
	attr.set_value(attr_AvailableDevices_read);
	
	/*----- PROTECTED REGION END -----*/	//	Ows::read_AvailableDevices
}

//--------------------------------------------------------
/**
 *	Read attribute PowerSupply related method
 *	Description: 
 *
 *	Data type:	Tango::DevUShort
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void Ows::read_PowerSupply(Tango::Attribute &attr)
{
	DEBUG_STREAM << "Ows::read_PowerSupply(Tango::Attribute &attr) entering... " << endl;
	Tango::DevUShort	*att_value = get_PowerSupply_data_ptr(attr.get_name());
	/*----- PROTECTED REGION ID(Ows::read_PowerSupply) ENABLED START -----*/
	//	Set the attribute value
	#define MAX_SERIAL_NUMBER_LENGTH 16
	char sn[MAX_SERIAL_NUMBER_LENGTH+1];
	sscanf (attr.get_name().c_str(),"%16s", sn);

	map<string, Sensor>::iterator it = Sensors.find(sn);

	stringstream oid;
	switch (it->second.type) {
		case DS18B20:
			oid << "EDS-MIB::owDS18B20PwrSupply." << it->second.idx;
			break;
		case DS2438:
		case EDS0065:
		case EDS0068:
		case EDS0071:
			Tango::Except::throw_exception("",
				"Unsupported sensor",
				"Ows::add_dynamic_attributes()");
	}

	get(oid.str(), *att_value);

	attr.set_value(att_value);
	
	/*----- PROTECTED REGION END -----*/	//	Ows::read_PowerSupply
}
//--------------------------------------------------------
/**
 *	Read attribute Resolution related method
 *	Description: 
 *
 *	Data type:	Tango::DevUShort
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void Ows::read_Resolution(Tango::Attribute &attr)
{
	DEBUG_STREAM << "Ows::read_Resolution(Tango::Attribute &attr) entering... " << endl;
	Tango::DevUShort	*att_value = get_Resolution_data_ptr(attr.get_name());
	/*----- PROTECTED REGION ID(Ows::read_Resolution) ENABLED START -----*/
	//	Set the attribute value
	#define MAX_SERIAL_NUMBER_LENGTH 16
	char sn[MAX_SERIAL_NUMBER_LENGTH+1];
	sscanf (attr.get_name().c_str(),"%16s", sn);

	map<string, Sensor>::iterator it = Sensors.find(sn);

	stringstream oid;
	switch (it->second.type) {
		case DS18B20:
			oid << "EDS-MIB::owDS18B20Resolution." << it->second.idx;
			break;
		case DS2438:
		case EDS0065:
		case EDS0068:
		case EDS0071:
			Tango::Except::throw_exception("",
				"Unsupported sensor",
				"Ows::add_dynamic_attributes()");
	}

	get(oid.str(), *att_value);

	attr.set_value(att_value);
	
	/*----- PROTECTED REGION END -----*/	//	Ows::read_Resolution
}
//--------------------------------------------------------
/**
 *	Read attribute Temperature related method
 *	Description: 
 *
 *	Data type:	Tango::DevFloat
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void Ows::read_Temperature(Tango::Attribute &attr)
{
	DEBUG_STREAM << "Ows::read_Temperature(Tango::Attribute &attr) entering... " << endl;
	Tango::DevFloat	*att_value = get_Temperature_data_ptr(attr.get_name());
	/*----- PROTECTED REGION ID(Ows::read_Temperature) ENABLED START -----*/
	//	Set the attribute value
	#define MAX_SERIAL_NUMBER_LENGTH 16
	char sn[MAX_SERIAL_NUMBER_LENGTH+1];
	sscanf (attr.get_name().c_str(),"%16s", sn);

	map<string, Sensor>::iterator it = Sensors.find(sn);
	
	stringstream oid;
	switch (it->second.type) {
		case DS18B20:
			oid << "EDS-MIB::owDS18B20Temperature.";
			break;
		case DS2438:
			oid << "EDS-MIB::owDS2438Temperature.";
			break;
		case EDS0065:
			oid << "EDS-MIB::owEDS0065Temperature.";
			break;
		case EDS0068:
			oid << "EDS-MIB::owEDS0068Temperature.";
			break;
		case EDS0071:
			oid << "EDS-MIB::owDevices.18.1.1.";
			break;
	}
	oid << it->second.idx;

	string value;
	get(oid.str(), value);
	if (value[0] == '"')
		value = value.substr(1, value.size()-2);
	convert(value, *att_value);

	attr.set_value(att_value);

	/*----- PROTECTED REGION END -----*/	//	Ows::read_Temperature
}
//--------------------------------------------------------
/**
 *	Read attribute Humidity related method
 *	Description: 
 *
 *	Data type:	Tango::DevFloat
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void Ows::read_Humidity(Tango::Attribute &attr)
{
	DEBUG_STREAM << "Ows::read_Humidity(Tango::Attribute &attr) entering... " << endl;
	Tango::DevFloat	*att_value = get_Humidity_data_ptr(attr.get_name());
	/*----- PROTECTED REGION ID(Ows::read_Humidity) ENABLED START -----*/
	//	Set the attribute value
	#define MAX_SERIAL_NUMBER_LENGTH 16
	char sn[MAX_SERIAL_NUMBER_LENGTH+1];
	sscanf (attr.get_name().c_str(),"%16s", sn);

	map<string, Sensor>::iterator it = Sensors.find(sn);
	
	stringstream oid;
	switch (it->second.type) {
		case DS2438:
			oid << "EDS-MIB::owDS2438Entry.5.";
			break;		
		case EDS0065:
			oid << "EDS-MIB::owEDS0065Humidity.";
			break;
		case EDS0068:
			oid << "EDS-MIB::owEDS0068Humidity.";
			break;
		case EDS0071:
		case DS18B20:
			Tango::Except::throw_exception("",
					"Unsupported sensor",
					"Ows::add_dynamic_attributes()");
	}
	oid << it->second.idx;

	string value;
	get(oid.str(), value);
	if (value[0] == '"')
		value = value.substr(1, value.size()-2);
	convert(value, *att_value);

	attr.set_value(att_value);
	
	/*----- PROTECTED REGION END -----*/	//	Ows::read_Humidity
}
//--------------------------------------------------------
/**
 *	Read attribute Counter related method
 *	Description: 
 *
 *	Data type:	Tango::DevULong
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void Ows::read_Counter(Tango::Attribute &attr)
{
	DEBUG_STREAM << "Ows::read_Counter(Tango::Attribute &attr) entering... " << endl;
	Tango::DevULong	*att_value = get_Counter_data_ptr(attr.get_name());
	/*----- PROTECTED REGION ID(Ows::read_Counter) ENABLED START -----*/
	//	Set the attribute value
	#define MAX_SERIAL_NUMBER_LENGTH 16
	char sn[MAX_SERIAL_NUMBER_LENGTH+1];
	sscanf (attr.get_name().c_str(),"%16s", sn);

	map<string, Sensor>::iterator it = Sensors.find(sn);

	stringstream oid;
	switch (it->second.type) {
		case EDS0071:
			oid << "EDS-MIB::owDevices.18.1.2." << it->second.idx;
			break;
		case DS18B20:
		case DS2438:
		case EDS0065:
		case EDS0068:
			Tango::Except::throw_exception("",
					"Unsupported sensor",
					"Ows::add_dynamic_attributes()");
	}

	get(oid.str(), *att_value);
	attr.set_value(att_value);

	/*----- PROTECTED REGION END -----*/	//	Ows::read_Counter
}
//--------------------------------------------------------
/**
 *	Read attribute Pressure related method
 *	Description: 
 *
 *	Data type:	Tango::DevFloat
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void Ows::read_Pressure(Tango::Attribute &attr)
{
	DEBUG_STREAM << "Ows::read_Pressure(Tango::Attribute &attr) entering... " << endl;
	Tango::DevFloat	*att_value = get_Pressure_data_ptr(attr.get_name());
	/*----- PROTECTED REGION ID(Ows::read_Pressure) ENABLED START -----*/
	//	Set the attribute value
	#define MAX_SERIAL_NUMBER_LENGTH 16
	char sn[MAX_SERIAL_NUMBER_LENGTH+1];
	sscanf (attr.get_name().c_str(),"%16s", sn);

	map<string, Sensor>::iterator it = Sensors.find(sn);

	stringstream oid;
	switch (it->second.type) {
		case EDS0068:
			oid << "EDS-MIB::owEDS0068BarometricPressureMb." << it->second.idx;
			break;
		case DS18B20:
		case DS2438:
		case EDS0065:
		case EDS0071:
			Tango::Except::throw_exception("",
				"Unsupported sensor",
				"Ows::add_dynamic_attributes()");
	}

	string value;
	get(oid.str(), value);
	if (value[0] == '"')
		value = value.substr(1, value.size()-2);
	convert(value, *att_value);

	attr.set_value(att_value);
	
	/*----- PROTECTED REGION END -----*/	//	Ows::read_Pressure
}
//--------------------------------------------------------
/**
 *	Read attribute Light related method
 *	Description: 
 *
 *	Data type:	Tango::DevULong
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void Ows::read_Light(Tango::Attribute &attr)
{
	DEBUG_STREAM << "Ows::read_Light(Tango::Attribute &attr) entering... " << endl;
	Tango::DevULong	*att_value = get_Light_data_ptr(attr.get_name());
	/*----- PROTECTED REGION ID(Ows::read_Light) ENABLED START -----*/
	//	Set the attribute value
	#define MAX_SERIAL_NUMBER_LENGTH 16
	char sn[MAX_SERIAL_NUMBER_LENGTH+1];
	sscanf (attr.get_name().c_str(),"%16s", sn);

	map<string, Sensor>::iterator it = Sensors.find(sn);

	stringstream oid;
	switch (it->second.type) {
		case EDS0068:
			oid << "EDS-MIB::owEDS0068Light." << it->second.idx;
			break;
		case DS18B20:
		case DS2438:
		case EDS0065:
		case EDS0071:
			Tango::Except::throw_exception("",
				"Unsupported sensor",
				"Ows::add_dynamic_attributes()");
	}
	
	string value;
	get(oid.str(), value);
	if (value[0] == '"')
		value = value.substr(1, value.size()-2);
	convert(value, *att_value);

	attr.set_value(att_value);
	
	/*----- PROTECTED REGION END -----*/	//	Ows::read_Light
}
//--------------------------------------------------------
/**
 *	Read attribute Health related method
 *	Description: 
 *
 *	Data type:	Tango::DevUShort
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void Ows::read_Health(Tango::Attribute &attr)
{
	DEBUG_STREAM << "Ows::read_Health(Tango::Attribute &attr) entering... " << endl;
	Tango::DevUShort	*att_value = get_Health_data_ptr(attr.get_name());
	/*----- PROTECTED REGION ID(Ows::read_Health) ENABLED START -----*/
	//	Set the attribute value
	#define MAX_SERIAL_NUMBER_LENGTH 16
	char sn[MAX_SERIAL_NUMBER_LENGTH+1];
	sscanf (attr.get_name().c_str(),"%16s", sn);

	map<string, Sensor>::iterator it = Sensors.find(sn);

	stringstream oid;
	oid << "EDS-MIB::owDeviceHealth." << it->second.idx;

	get(oid.str(), *att_value);

	attr.set_value(att_value);
	
	/*----- PROTECTED REGION END -----*/	//	Ows::read_Health
}
//--------------------------------------------------------
/**
 *	Method      : Ows::add_dynamic_attributes()
 *	Description : Create the dynamic attributes if any
 *                for specified device.
 */
//--------------------------------------------------------
void Ows::add_dynamic_attributes()
{
	//	Example to add dynamic attribute:
	//	Copy inside the following protected area to create instance(s) at startup.
	//	add_PowerSupply_dynamic_attribute("MyPowerSupplyAttribute");
	//	add_Resolution_dynamic_attribute("MyResolutionAttribute");
	//	add_Temperature_dynamic_attribute("MyTemperatureAttribute");
	//	add_Humidity_dynamic_attribute("MyHumidityAttribute");
	//	add_Counter_dynamic_attribute("MyCounterAttribute");
	//	add_Pressure_dynamic_attribute("MyPressureAttribute");
	//	add_Light_dynamic_attribute("MyLightAttribute");
	//	add_Health_dynamic_attribute("MyHealthAttribute");
	
	/*----- PROTECTED REGION ID(Ows::add_dynamic_attributes) ENABLED START -----*/
	
	//	Add your own code to create and add dynamic attributes if any
	Sensors.clear();

	try {
		for (unsigned int i=0; i<number_of_sensors; ++i) {
			stringstream index;
			index << i;

			unsigned int dt;
			get("EDS-MIB::owDeviceType." + index.str(), dt);

			string sn;
			get("EDS-MIB::owDeviceROM." + index.str(), sn);
			if (sn[0] == '"')
				sn = sn.substr(1, sn.size()-2);

			Sensor sensor;
			sensor.idx = i;
			
			switch(dt) {
				case 3:
					add_PowerSupply_dynamic_attribute(sn + "_PowerSupply");
					add_Resolution_dynamic_attribute(sn + "_Resolution");
					sensor.type = DS18B20;
					break;
				case 5:
					add_Humidity_dynamic_attribute(sn + "_Humidity");
					sensor.type = DS2438;
					break;
				case 10:
					add_Humidity_dynamic_attribute(sn + "_Humidity");
					sensor.type = EDS0065;
					break;
				case 13:
					add_Humidity_dynamic_attribute(sn + "_Humidity");
					add_Pressure_dynamic_attribute(sn + "_Pressure");
					add_Light_dynamic_attribute(sn + "_Light");
					sensor.type = EDS0068;
					break;
				case 16:
					add_Counter_dynamic_attribute(sn + "_Counter");
					sensor.type = EDS0071;
					break;
				default:
					Tango::Except::throw_exception("",
						"Unsupported sensor",
						"Ows::add_dynamic_attributes()");
			}
			add_Temperature_dynamic_attribute(sn + "_Temperature");
			add_Health_dynamic_attribute(sn + "_Health");

			Sensors[sn] = sensor;
		}
	} catch (Tango::DevFailed &e) {
		set_state(Tango::FAULT);
		init_error = "Initialization failed: " + string(e.errors[0].desc);
	} catch (...) {
		set_state(Tango::UNKNOWN);
		init_error = "Initialization failed: Unknown error";
	}
	
	/*----- PROTECTED REGION END -----*/	//	Ows::add_dynamic_attributes
}

//--------------------------------------------------------
/**
 *	Method      : Ows::add_dynamic_commands()
 *	Description : Create the dynamic commands if any
 *                for specified device.
 */
//--------------------------------------------------------
void Ows::add_dynamic_commands()
{
	/*----- PROTECTED REGION ID(Ows::add_dynamic_commands) ENABLED START -----*/
	
	//	Add your own code to create and add dynamic commands if any
	
	/*----- PROTECTED REGION END -----*/	//	Ows::add_dynamic_commands
}

/*----- PROTECTED REGION ID(Ows::namespace_ending) ENABLED START -----*/

//	Additional Methods
void Ows::check_init()
{
	DEBUG_STREAM << "Ows::check_init() entering... " << endl;
	if (! init_error.empty())
		Tango::Except::throw_exception("",
				init_error.c_str(),
				"Ows::check_init()");
}

void Ows::check_state() {
	const string expected_sysname = "OWServer_v2-Enet";

	string sysname;
	get("SNMPv2-MIB::sysName.0", sysname);

	if (sysname[0] == '"')
		sysname = sysname.substr(1, sysname.size()-2);

	if (sysname != expected_sysname) {
		Tango::Except::throw_exception("",
			"Unsupported system",
			"Ows::check_state()");
	}
}

/*----- PROTECTED REGION END -----*/	//	Ows::namespace_ending
} //	namespace
